@@ -170,12 +170,28 @@ USER_AGENT = "{name}/{version} ({platform})".format(name=__name__,
 
 _expected_exceptions = exceptions.network_exceptions + (exceptions.DXAPIError, ssl.SSLError)
 
+def _process_method_url_headers(method, url, headers):
+    if callable(url):
+        _url, _headers = url()
+        _headers.update(headers)
+    else:
+        _url, _headers = url, headers
+    # When *data* is bytes but *headers* contains Unicode text, httplib tries to concatenate them and decode
+    # *data*, which should not be done. Also, per HTTP/1.1 headers must be encoded with MIME, but we'll
+    # disregard that here, and just encode them with the Python default (ascii) and fail for any non-ascii
+    # content. See http://tools.ietf.org/html/rfc3987 for a discussion of encoding URLs.
+    # TODO: ascertain whether this is a problem in Python 3/make test
+    if USING_PYTHON2:
+        return method.encode(), _url.encode('utf-8'), {k.encode(): v.encode() for k, v in _headers.items()}
+    else:
+        return method, _url, _headers
+
 def DXHTTPRequest(resource, data, method='POST', headers=None, auth=True, timeout=600,
                   use_compression=None, jsonify_data=True, want_full_response=False,
                   decode_response_body=True, prepend_srv=True, session_handler=None,
                   max_retries=DEFAULT_RETRIES, always_retry=False, **kwargs):
     '''
-    :param resource: API server route, e.g. "/record/new"
+    :param resource: API server route, e.g. "/record/new". If *prepend_srv* is False, a fully qualified URL is expected. If this argument is a callable, it will be called just before each request attempt, and expected to return a tuple (URL, headers). Headers returned by the callback are updated with *headers* (including headers set by this method).
     :type resource: string
     :param data: Content of the request body
     :type data: list or dict, if *jsonify_data* is True; or string or file-like object, otherwise
@@ -259,16 +275,6 @@ def DXHTTPRequest(resource, data, method='POST', headers=None, auth=True, timeou
             raise exceptions.DXError("Snappy compression requested, but the snappy module is unavailable")
         headers['accept-encoding'] = 'snappy'
 
-    # When *data* is bytes but *headers* contains Unicode text, httplib tries to concatenate them and decode *data*,
-    # which should not be done. Also, per HTTP/1.1 headers must be encoded with MIME, but we'll disregard that here, and
-    # just encode them with the Python default (ascii) and fail for any non-ascii content.
-    # See http://tools.ietf.org/html/rfc3987 for a discussion of encoding URLs.
-    # TODO: ascertain whether this is a problem in Python 3/make test
-    if USING_PYTHON2:
-        headers = {k.encode(): v.encode() for k, v in headers.items()}
-        url = url.encode('utf-8')
-        method = method.encode()
-
     # If the input is a buffer, its data gets consumed by
     # requests.request (moving the read position). Record the initial
     # buffer position so that we can return to it if the request fails
@@ -283,7 +289,8 @@ def DXHTTPRequest(resource, data, method='POST', headers=None, auth=True, timeou
         streaming_response_truncated = False
         response = None
         try:
-            response = session_handler.request(method, url, data=data, headers=headers, timeout=timeout, auth=auth,
+            _method, _url, _headers = _process_method_url_headers(method, url, headers)
+            response = session_handler.request(_method, _url, headers=_headers, data=data, timeout=timeout, auth=auth,
                                                **kwargs)
 
             if _UPGRADE_NOTIFY and response.headers.get('x-upgrade-info', '').startswith('A recommended update is available') and not os.environ.has_key('_ARGCOMPLETE'):
