@@ -627,7 +627,7 @@ from .dxanalysis import DXAnalysis
 from .dxapplet import DXExecutable, DXApplet
 from .dxapp import DXApp
 from .dxworkflow import DXWorkflow, new_dxworkflow
-from .auth import user_info
+from .auth import user_info, whoami
 from .dxdataobject_functions import dxlink, is_dxlink, get_dxlink_ids, get_handler, describe, get_details, remove
 from .search import (find_data_objects, find_executions, find_jobs, find_analyses, find_projects, find_apps,
                      find_one_data_object, find_one_project, find_one_app)
