@@ -72,6 +72,9 @@ if USING_PYTHON2:
             userhome = pwent.pw_dir
         userhome = userhome.rstrip('/')
         return (userhome + path[i:]) or '/'
+    if os.name == 'nt':
+        # The POSIX os.path.expanduser doesn't work on NT, so just leave it be
+        expanduser = os.path.expanduser
 else:
     from io import StringIO, BytesIO
     builtin_str = str
@@ -129,6 +132,8 @@ def decode_command_line_args():
 
 class _Environ(object):
     def __getitem__(self, item):
+        if not isinstance(item, bytes):
+            item = item.encode(sys_encoding)
         value = os.environ[item]
         if isinstance(value, bytes):
             value = value.decode(sys_encoding)
@@ -142,6 +147,8 @@ class _Environ(object):
         os.environ[varname] = value
 
     def __contains__(self, item):
+        if not isinstance(item, bytes):
+            item = item.encode(sys_encoding)
         return True if item in os.environ else False
 
     def __getattr__(self, attr):
